#!/bin/bash
APPPROTECTION_VERSION=1.6.7.3

is_installed()
{
    [ -f /usr/lib/systemd/system/AppProtectionService-install.service ]
}

pending_reboot()
{
    if [ -f /usr/lib/systemd/system/AppProtectionService-remove.service ]; then
        echo -e "\e[31mA reboot is required as an uninstall is already pending\e[0m"
        exit 1
    fi
}

install()
{
    if is_installed; then
        echo -e "\e[31mAppProtectionService is already installed\e[0m"
        exit 1
    fi
    pending_reboot
    echo "Installing AppProtectionService and dependencies..."
    tar -C / -zxf AppProtection-service-$APPPROTECTION_VERSION.tar.gz --strip-components=1 AppProtectionService-install
    ln -sf /usr/local/lib/AppProtection/libAppProtection.so.$APPPROTECTION_VERSION /usr/local/lib/AppProtection/libAppProtection.so
    echo "Starting AppProtectionService... please wait."
    systemctl daemon-reload
    systemctl enable AppProtectionService-install &> /dev/null
    systemctl start AppProtectionService-install
    mv /etc/preload_lib /etc/ld.so.preload
    echo "Installation complete."
    exit 0
}

uninstall()
{
    pending_reboot
    if ! is_installed; then
        echo -e "\e[31mAppProtectionService is not installed\e[0m"
        exit 1
    else
        rm -rf /etc/ld.so.preload
        echo "Stopping AppProtectionService..."
        systemctl disable AppProtectionService-install &> /dev/null
        systemctl stop AppProtectionService-install
        echo "Removing installation files..."
        rm -rf /usr/lib/systemd/system/AppProtectionService-install.service
        tar -C / -zxf AppProtection-service-$APPPROTECTION_VERSION.tar.gz --strip-components=1 AppProtectionService-remove
        systemctl daemon-reload
        systemctl enable AppProtectionService-remove &> /dev/null
        echo "Uninstallation complete. Please reboot the system in order to complete the removal."
        exit 0
    fi
}

check_argument()
{
    if [ "$1" = "" ]; then
        echo -e "\e[31mNo version specifed for requested operation\e[0m"
        exit 1
    elif ! [ -f AppProtection-service-$1.tar.gz ]; then
        echo -e "\e[31mRequested version is not available for the operation\e[0m"
        exit 1
    fi
    mkdir -p /opt/AppProtection
    tar -C /opt/AppProtection -zxf AppProtection-service-$APPPROTECTION_VERSION.tar.gz --strip-components=5 AppProtectionService-install/usr/local/bin/AppProtection/.version
    diff /opt/AppProtection/.version /usr/local/bin/AppProtection/.version &> /dev/null
}

upgrade()
{
    pending_reboot
    if ! is_installed; then
        echo -e "\e[31mAppProtectionService is not installed\e[0m"
        exit 1
    elif check_argument $1; then
        rm -rf /opt/AppProtection
        echo -e "\e[31mRequested version is already installed\e[0m"
        exit 1
    else
        echo "Upgading AppProtectionService to version: $1"
        systemctl stop AppProtectionService-install
        tar -C /usr/local -zxf AppProtection-service-$1.tar.gz --strip-components=3 AppProtectionService-install
        ln -sf /usr/local/lib/AppProtection/libAppProtection.so.$1 /usr/local/lib/AppProtection/libAppProtection.so
        echo "Restarting AppProtectionService... please wait."
        systemctl start AppProtectionService-install
        rm -rf /opt/AppProtection
        echo "Upgrade complete."
    fi
}

echo -e "\e[1mAppProtectionService Installation Script v1.0\e[0m"
if [[ $EUID -ne 0 ]]; then
   echo -e "\e[31mThis installation script must be run as root\e[0m" 
   exit 1
fi

if [ "$1" = "--install" ]; then
    install
elif [ "$1" = "--uninstall" ]; then
    uninstall
elif [ "$1" = "--help" ]; then
    echo -e "Options:\n\t\e[1m--install \e[0m(Perform a clean installation of the service)\n\t\e[1m--uninstall \e[0m(Removes service and installation files, reboot required)\n\t\e[1m--upgrade [\e[0;32mVERSION\e[0m] (Upgrades an already installed and running service)"
    exit 0
elif [ "$1" = "--upgrade" ]; then
    upgrade $2
else
    echo "Incorrect command line arguments, use --help for details"
    exit 1
fi
